@@ -8,11 +8,11 @@ class TestInfluxDBClient3(unittest.TestCase):
 
     @patch('influxdb_client_3._InfluxDBClient')
     @patch('influxdb_client_3._WriteApi')
-    @patch('influxdb_client_3.FlightClient')
-    def setUp(self, mock_flight_client, mock_write_api, mock_influx_db_client):
+    @patch('influxdb_client_3._QueryApi')
+    def setUp(self, mock_query_api, mock_write_api, mock_influx_db_client):
         self.mock_influx_db_client = mock_influx_db_client
         self.mock_write_api = mock_write_api
-        self.mock_flight_client = mock_flight_client
+        self.mock_query_api = mock_query_api
         self.client = InfluxDBClient3(
             host="localhost",
             org="my_org",
@@ -25,7 +25,7 @@ class TestInfluxDBClient3(unittest.TestCase):
         self.assertEqual(self.client._database, "my_db")
         self.assertEqual(self.client._client, self.mock_influx_db_client.return_value)
         self.assertEqual(self.client._write_api, self.mock_write_api.return_value)
-        self.assertEqual(self.client._flight_client, self.mock_flight_client.return_value)
+        self.assertEqual(self.client._query_api, self.mock_query_api.return_value)
 
 
 if __name__ == '__main__':
